@@ -1,28 +1,42 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-Created on Wed Feb  5 13:33:33 2020
-
-@author: butkus
-"""
+#==========================================================================
+# 
+#--------------------------------------------------------------------------
+# Copyright (c) 2022 Light Conversion, UAB
+# All rights reserved.
+# www.lightcon.com
+#==========================================================================
 import json
 import urllib
 import urllib.error
 import urllib.request
 import urllib.parse
 import time
+import http
 
 class HTTP_methods:    
+    retry_on_incomplete_read = True
+
     def _open(self, page_url):
         return urllib.request.urlopen(self.url+page_url).read().decode('utf-8')
         
     def _get (self, command):
         time_init = time.perf_counter()
-        try:
-            data = json.loads(urllib.request.urlopen(self.url+command).read().decode('utf-8'))
-        except urllib.error.HTTPError as e:
-            error_string = e.read().decode('utf-8', 'ignore')
-            print (error_string)
-            return error_string
+        cont = True
+
+        while cont:
+            try:
+                data = json.loads(urllib.request.urlopen(self.url+command).read().decode('utf-8'))
+                cont = False
+            except urllib.error.HTTPError as e:
+                error_string = e.read().decode('utf-8', 'ignore')
+                print (error_string)
+                return error_string
+            except http.client.IncompleteRead:
+                cont = True and self.retry_on_incomplete_read
+                if not self.silent:
+                    print ('Incomplete read')
         
         if not self.silent:
             print (command + " : {:.3f} ms".format((time.perf_counter()-time_init)*1000))
