@@ -11,6 +11,7 @@
 import json
 import socket
 from ..common.http_methods import HTTP_methods
+from .harpia_leprecan_provider import HarpiaLepreCanProvider
     
 class Harpia (HTTP_methods):
     """REST API interaction logic with Harpia spectrometer"""
@@ -22,6 +23,7 @@ class Harpia (HTTP_methods):
         self.url = 'http://{}:{}/{}/'.format(ip_address, port, version)        
         self.connected = self._get('Basic') != {}
         if self.connected:
+            self.can = HarpiaLepreCanProvider(self)
             print ('Harpia initialized at', self.url)
         
     #==============================================================================
